@@ -1,5 +1,7 @@
+from urllib.parse import urljoin
+from urllib.parse import urlparse
+
 from flask import request
-from urllib.parse import urlparse, urljoin
 
 
 # from https://security.openstack.org/guidelines/dg_avoid-unvalidated-redirects.html
