@@ -1,13 +1,16 @@
 import os
+
 import pytest
 from click.testing import CliRunner
+
 from shopyo.api.cli import cli
-from shopyo.api.constants import SEP_CHAR, SEP_NUM
+from shopyo.api.constants import SEP_CHAR
+from shopyo.api.constants import SEP_NUM
 
 pytestmark = pytest.mark.cli_unit
 
 
-@pytest.fixture(scope='session')
+@pytest.fixture(scope="session")
 def cli_runner():
     """Fixture that returns a helper function to run the shopyo cli."""
     runner = CliRunner()
@@ -43,9 +46,7 @@ class TestCliCreateBox:
 
         assert result.exit_code == 0
         assert os.path.exists(os.path.join("modules", "box__foo"))
-        assert os.path.exists(
-            os.path.join("modules", "box__foo", "box_info.json")
-        )
+        assert os.path.exists(os.path.join("modules", "box__foo", "box_info.json"))
         assert expected in result.output
 
 
@@ -67,10 +68,7 @@ class TestCliClean:
         os.chdir(tmpdir)
         runner = flask_app.test_cli_runner(mix_stderr=False)
         result = runner.invoke(cli, ["clean", "-v"])
-        expected_out = (
-            "[x] all tables dropped\n"
-            "[x] __pycache__ successfully deleted\n"
-        )
+        expected_out = "[x] all tables dropped\n[x] __pycache__ successfully deleted\n"
         expected_err_shopyo_db = (
             f"[ ] unable to delete {os.path.join(tmpdir, 'shopyo.db')}"
         )
@@ -104,10 +102,7 @@ class TestCliClean:
         os.chdir(tmpdir)
         runner = flask_app.test_cli_runner()
         result = runner.invoke(cli, ["clean", "-v"])
-        expected_out = (
-            "[x] all tables dropped\n"
-            "[x] __pycache__ successfully deleted\n"
-        )
+        expected_out = "[x] all tables dropped\n[x] __pycache__ successfully deleted\n"
         expected_err_shopyo_db = (
             f"[ ] unable to delete {os.path.join(tmpdir, 'shopyo.db')}"
         )
@@ -148,9 +143,7 @@ class TestCliClean:
         os.chdir(tmpdir)
         runner = flask_app.test_cli_runner()
         result = runner.invoke(cli, ["clean", "-v"])
-        expected_out = (
-            "[x] all tables dropped\n" "[x] __pycache__ successfully deleted\n"
-        )
+        expected_out = "[x] all tables dropped\n[x] __pycache__ successfully deleted\n"
         expected_err_shopyo_db = (
             f"[ ] unable to delete {os.path.join(tmpdir, 'shopyo.db')}"
         )
@@ -182,6 +175,24 @@ class TestCliClean:
         assert os.path.exists(path1)
         assert os.path.exists(path2)
 
+    def test_clean_on_skip_shopyo_db_file(self, tmpdir, flask_app):
+        """
+        run `shopyo clean2 -v` on the following test directory:
+
+        <some-unique-tmpdir>/
+            shopyo.db
+        """
+        shopyo_db = tmpdir.join("shopyo.db")
+        shopyo_db.write("content")
+        os.chdir(tmpdir)
+        runner = flask_app.test_cli_runner()
+        result = runner.invoke(cli, ["clean", "--no-clear-db", "-v"])
+        part_expected_out = "[ ] db clearing skipped"
+
+        assert result.exit_code == 0
+        assert os.path.exists(shopyo_db) is True
+        assert part_expected_out in result.output
+
     def test_clean_on_shopyo_db_file(self, tmpdir, flask_app):
         """
         run `shopyo clean2 -v` on the following test directory:
@@ -194,17 +205,42 @@ class TestCliClean:
         os.chdir(tmpdir)
         runner = flask_app.test_cli_runner()
         result = runner.invoke(cli, ["clean", "-v"])
-        expected_out = (
-            "[x] all tables dropped\n"
-            "[ ] __pycache__ doesn't exist\n"
-            f"[x] file '{os.path.join(tmpdir, 'shopyo.db')}' "
-            "successfully deleted\n"
-            f"[ ] unable to delete {os.path.join(tmpdir, 'migrations')}"
+        expected_out1 = "[x] all tables dropped"
+        expected_out2 = "[ ] __pycache__ doesn't exist"
+        expected_out3 = (
+            f"[x] file '{os.path.join(tmpdir, 'shopyo.db')}' successfully deleted"
         )
+        expected_out4 = f"[ ] unable to delete {os.path.join(tmpdir, 'migrations')}"
 
         assert result.exit_code == 0
         assert os.path.exists(shopyo_db) is False
-        assert expected_out in result.output
+        assert expected_out1 in result.output
+        assert expected_out2 in result.output
+        assert expected_out3 in result.output
+        assert expected_out4 in result.output
+
+    def test_clean_on_skip_migration_folder(self, tmpdir, flask_app):
+        """
+        run `shopyo clean2 -v` on the following test directory:
+
+        <some-unique-tmpdir>/
+            migrations/
+                env.py
+                alembic.ini
+        """
+        migrations_path = tmpdir.mkdir("migrations")
+        env = migrations_path.join("env.py")
+        alembic = migrations_path.join("alembic.ini")
+        env.write("content-env")
+        alembic.write("content-alembic")
+        os.chdir(tmpdir)
+        runner = flask_app.test_cli_runner(mix_stderr=False)
+        result = runner.invoke(cli, ["clean", "--no-clear-migration", "-v"])
+        part_expected_out = "[ ] migration folder delete skipped"
+
+        assert result.exit_code == 0
+        assert os.path.exists(migrations_path) is True
+        assert part_expected_out in result.stdout
 
     def test_clean_on_migration_folder(self, tmpdir, flask_app):
         """
@@ -274,17 +310,21 @@ class TestCliClean:
         os.chdir(shopyo_path)
         runner = flask_app.test_cli_runner()
         result = runner.invoke(cli, ["clean", option])
-        expected_out = (
-            "[x] all tables dropped\n"
-            "[x] __pycache__ successfully deleted\n"
-            f"[x] file '{os.path.join(shopyo_path, 'shopyo.db')}' "
-            "successfully deleted\n"
-            f"[x] folder '{os.path.join(shopyo_path, 'migrations')}' "
-            "successfully deleted\n"
+        expected_out1 = "[x] all tables dropped"
+        expected_out2 = "[x] __pycache__ successfully deleted"
+        expected_out3 = (
+            f"[x] file '{os.path.join(shopyo_path, 'shopyo.db')}' successfully deleted"
+        )
+        expected_out4 = (
+            f"[x] folder '{os.path.join(shopyo_path, 'migrations')}' successfully"
+            " deleted\n"
         )
 
         assert result.exit_code == 0
-        assert expected_out in result.output
+        assert expected_out1 in result.output
+        assert expected_out2 in result.output
+        assert expected_out3 in result.output
+        assert expected_out4 in result.output
         assert os.path.exists(migrations_path) is False
         assert os.path.exists(pycache_path1) is False
         assert os.path.exists(pycache_path2) is False
@@ -332,7 +372,7 @@ class TestCliClean:
         os.chdir(tmpdir)
         runner = flask_app.test_cli_runner(mix_stderr=False)
         result = runner.invoke(cli, ["clean"])
-        expect_out = "Cleaning...\n" + SEP_CHAR * SEP_NUM + "\n\n"
+        expect_out = "Cleaning...\n" + SEP_CHAR * SEP_NUM + "\n"
 
         assert result.exit_code == 0
         assert expect_out in result.output
@@ -349,7 +389,7 @@ class TestCliClean:
         os.chdir(tmpdir)
         runner = flask_app.test_cli_runner(mix_stderr=False)
         result = runner.invoke(cli, ["clean"])
-        expect_out1 = "Cleaning...\n" + SEP_CHAR * SEP_NUM + "\n\n"
+        expect_out1 = "Cleaning...\n" + SEP_CHAR * SEP_NUM + "\n"
         expect_out2 = "[x] __pycache__ successfully deleted\n"
         expect_out3 = "[ ] unable to delete"
 
@@ -366,11 +406,8 @@ class TestCliClean:
 
 @pytest.mark.usefixtures("restore_cwd")
 class TestCliNew:
-
     @pytest.mark.parametrize("proj,parent", [("", "foo"), ("bar", "")])
-    def test_new_projname_already_exists(
-        self, cli_runner, proj, parent, tmp_path
-    ):
+    def test_new_projname_already_exists(self, cli_runner, proj, parent, tmp_path):
         name = proj or parent
         parent_path = tmp_path / parent
         proj_path = parent_path / name
@@ -378,8 +415,7 @@ class TestCliNew:
         os.chdir(parent_path)
         result = cli_runner("new", proj)
         expected_out = (
-            f"[ ] Error: Unable to create new project. Path {proj_path}"
-            " exits"
+            f"[ ] Error: Unable to create new project. Path {proj_path} exits"
         )
 
         assert result.exit_code == 1
@@ -400,7 +436,7 @@ class TestCliNew:
 
         # create the parent folder for foo and none for bar proj
         temp_proj = tmp_path / parent
-        print(temp_proj)
+        # print(temp_proj)
         temp_proj.mkdir(exist_ok=True)
         # change to the parent folder (in case of bar it tmp_path while for foo
         # it is tmp_path/foo) and run the new command. For foo, there is no
@@ -426,26 +462,12 @@ class TestCliNew:
         assert os.path.exists(os.path.join(name, name, "__init__.py"))
         assert os.path.exists(os.path.join(name, name, "cli.py"))
         assert os.path.exists(os.path.join(name, "docs"))
-        assert os.path.exists(
-            os.path.join(name, "docs", "conf.py")
-        )
-        assert os.path.exists(
-            os.path.join(name, "docs", "_static")
-        )
-        assert os.path.exists(
-            os.path.join(
-                name, "docs", "_static", "custom.css"
-            )
-        )
-        assert os.path.exists(
-            os.path.join(name, "docs", "Makefile")
-        )
-        assert os.path.exists(
-            os.path.join(name, "docs", "index.rst")
-        )
-        assert os.path.exists(
-            os.path.join(name, "docs", "docs.rst")
-        )
+        assert os.path.exists(os.path.join(name, "docs", "conf.py"))
+        assert os.path.exists(os.path.join(name, "docs", "_static"))
+        assert os.path.exists(os.path.join(name, "docs", "_static", "custom.css"))
+        assert os.path.exists(os.path.join(name, "docs", "Makefile"))
+        assert os.path.exists(os.path.join(name, "docs", "index.rst"))
+        assert os.path.exists(os.path.join(name, "docs", "docs.rst"))
         assert not os.path.exists(os.path.join(name, name, "__main__.py"))
         assert not os.path.exists(os.path.join(name, name, "api"))
         assert not os.path.exists(os.path.join(name, name, ".tox"))
@@ -465,11 +487,10 @@ class TestCliInitialise:
 
 
 @pytest.mark.usefixtures("fake_foo_proj")
-class TestCliCreateModule:
-
+class TestCliStartapp:
     @pytest.mark.parametrize("mod", ["box_bar", "box__foo"])
     def test_create_invalid_modulename_with_box_prefix(self, cli_runner, mod):
-        result = cli_runner("createmodule", mod)
+        result = cli_runner("startapp", mod)
         expected_out = (
             f"[ ] Invalid MODULENAME '{mod}'. MODULENAME cannot start"
             " with box_ prefix\n"
@@ -480,10 +501,9 @@ class TestCliCreateModule:
 
     @pytest.mark.parametrize("box", ["box_bar", "boxfoo", "foo"])
     def test_create_module_with_invalid_box_name(self, cli_runner, box):
-        result = cli_runner("createmodule", "demo", box)
+        result = cli_runner("startapp", "demo", box)
         expected_out = (
-            f"[ ] Invalid BOXNAME '{box}'. "
-            "BOXNAME should start with 'box__' prefix\n"
+            f"[ ] Invalid BOXNAME '{box}'. BOXNAME should start with 'box__' prefix\n"
         )
 
         assert result.exit_code != 0
@@ -496,21 +516,21 @@ class TestCliCreateModule:
             ("foo", "box__default"),
             ("foo", ""),
             ("baz", "box__default"),
-            ("demo", "box__default")
-        ]
+            ("demo", "box__default"),
+        ],
     )
     def test_create_existing_module(self, cli_runner, mod, box, tmpdir):
-        result = cli_runner("createmodule", mod, box)
+        result = cli_runner("startapp", mod, box)
         expected_out = (
             f"[ ] Unable to create module '{mod}'. "
-            f"MODULENAME already exists inside modules/ at"
+            "MODULENAME already exists inside modules/ at"
         )
 
         assert result.exit_code != 0
         assert expected_out in result.output
 
     def test_create_modulename_not_alphanumeric(self, cli_runner):
-        result = cli_runner("createmodule", "my(demo)mod")
+        result = cli_runner("startapp", "my(demo)mod")
         expected_out = (
             "[ ] Error: MODULENAME is not valid, please use alphanumeric "
             "and underscore only\n"
@@ -520,7 +540,7 @@ class TestCliCreateModule:
         assert expected_out in result.output
 
     def test_create_boxname_not_alphanumeric(self, cli_runner):
-        result = cli_runner("createmodule", "mod", "box__?.game")
+        result = cli_runner("startapp", "mod", "box__?.game")
         expected_out = (
             "[ ] Error: BOXNAME is not valid, please use alphanumeric "
             "and underscore only\n"
@@ -535,10 +555,10 @@ class TestCliCreateModule:
             ("store", ""),  # create module
             ("store", "box__ecommerce"),  # create submodule and also box
             ("marketplace", "box__default"),  # create submodule but not box
-        ]
+        ],
     )
     def test_create_valid_modules(self, cli_runner, fake_foo_proj, mod, box):
-        result = cli_runner("createmodule", mod, box)
+        result = cli_runner("startapp", mod, box)
         module_path = os.path.join(fake_foo_proj, "modules", box, mod)
 
         assert result.exit_code == 0
@@ -546,9 +566,7 @@ class TestCliCreateModule:
         assert os.path.exists(os.path.join(module_path, "templates"))
         assert os.path.exists(os.path.join(module_path, "templates", mod))
         assert os.path.exists(
-            os.path.join(
-                module_path, "templates", mod, "blocks", "sidebar.html"
-            )
+            os.path.join(module_path, "templates", mod, "blocks", "sidebar.html")
         )
         assert os.path.exists(
             os.path.join(module_path, "templates", mod, "dashboard.html")
@@ -568,10 +586,8 @@ class TestCliCreateModule:
         assert os.path.exists(os.path.join(module_path, "global.py"))
 
     @pytest.mark.parametrize("opt", ["-v", "--verbose"])
-    def test_create_valid_module_with_verbose(
-        self, cli_runner, fake_foo_proj, opt
-    ):
-        result = cli_runner("createmodule", "store", opt)
+    def test_create_valid_module_with_verbose(self, cli_runner, fake_foo_proj, opt):
+        result = cli_runner("startapp", "store", opt)
         module_path = os.path.join(fake_foo_proj, "modules", "store")
         expected_out1 = "[x] Successfully created"
         expected_out2 = "created with content"
@@ -584,7 +600,6 @@ class TestCliCreateModule:
 
 @pytest.mark.usefixtures("fake_foo_proj")
 class TestCliCollectstatic:
-
     def test_collectstatic_with_default_src(self, cli_runner):
         result = cli_runner("collectstatic")
         expected_out1 = "Collecting static...\n" + SEP_CHAR * SEP_NUM + "\n\n"
@@ -608,7 +623,7 @@ class TestCliCollectstatic:
             ("box__default\\foo", "box__default/foo/foo.css"),
             ("modules/bar", "bar/bar.css"),
             ("modules\\box__default/foo", "box__default/foo/foo.css"),
-        ]
+        ],
     )
     def test_collectstatic_with_valid_arg(self, src, expected, cli_runner):
         result = cli_runner("collectstatic", src)
