@@ -1,4 +1,5 @@
 import pytest
+
 from shopyo.api import validators
 
 
@@ -9,10 +10,12 @@ class TestValidators:
         "url,expected",
         [
             ("google", False),
-            ("www.google.com", True), ("https://www.google.com", True),
-            ("localhost:3000", True), ("192.168.0.250", True),
-            ("2001:0db8:85a3:0000:0000:8a2e:0370:7334", True)
-        ]
+            ("www.google.com", True),
+            ("https://www.google.com", True),
+            ("localhost:3000", True),
+            ("192.168.0.250", True),
+            ("2001:0db8:85a3:0000:0000:8a2e:0370:7334", True),
+        ],
     )
     def test_is_valid_url(self, url, expected):
         result = validators.is_valid_url(url)
