@@ -1,41 +1,26 @@
 import json
 import os
 
+from flask import Blueprint
+from flask import render_template
+
+from shopyo.api.module import ModuleHelp
+from shopyo.api.templates import yo_render
+
 # from flask import url_for
 # from flask import redirect
 # from flask import flash
 # from flask import request
-from flask import Blueprint
-from flask import render_template
-from shopyo.api.templates import yo_render
-
 #
 # from shopyo.api.html import notify_success
 # from shopyo.api.forms import flash_errors
 # from shopyo.api.enhance import get_active_theme_dir
 # from shopyo.api.enhance import get_setting
-
 # from modules.box__ecommerce.shop.helpers import get_cart_data
 
-
-from modules.box__default.settings.helpers import get_setting
-
-dirpath = os.path.dirname(os.path.abspath(__file__))
-module_info = {}
-
-with open(dirpath + "/info.json") as f:
-    module_info = json.load(f)
-
-
-globals()["{}_blueprint".format(module_info["module_name"])] = Blueprint(
-    "{}".format(module_info["module_name"]),
-    __name__,
-    template_folder="",
-    url_prefix=module_info["url_prefix"],
-)
-
-
-module_blueprint = globals()["{}_blueprint".format(module_info["module_name"])]
+mhelp = ModuleHelp(__file__, __name__)
+globals()[mhelp.blueprint_str] = mhelp.blueprint
+module_blueprint = globals()[mhelp.blueprint_str]
 
 
 @module_blueprint.route("/")
@@ -48,7 +33,9 @@ def index():
 
     # return str(module_blueprint.template_folder)
 
-    return render_template(get_setting("ACTIVE_FRONT_THEME") + "/index.html")
+    # return render_template(get_setting("ACTIVE_FRONT_THEME") + "/index.html")
+
+    return render_template("www/index.html")
 
 
 @module_blueprint.route("/render_demo")
